// LICENSE : MIT
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFormatterList = exports.createFormatter = void 0;
const module_interop_1 = require("@textlint/module-interop");
const fs = require("fs");
const path = require("path");
const tryResolve = require("try-resolve");
const isFile = require("is-file");
const debug = require("debug")("textlint:@textlint/linter-formatter");
function createFormatter(formatterConfig) {
    const formatterName = formatterConfig.formatterName;
    debug(`formatterName: ${formatterName}`);
    let formatter;
    let formatterPath;
    if (fs.existsSync(formatterName)) {
        formatterPath = formatterName;
    }
    else if (fs.existsSync(path.resolve(process.cwd(), formatterName))) {
        formatterPath = path.resolve(process.cwd(), formatterName);
    }
    else {
        if (isFile(`${path.join(__dirname, "formatters/", formatterName)}.js`)) {
            formatterPath = `${path.join(__dirname, "formatters/", formatterName)}.js`;
        }
        else if (isFile(`${path.join(__dirname, "formatters/", formatterName)}.ts`)) {
            formatterPath = `${path.join(__dirname, "formatters/", formatterName)}.ts`;
        }
        else {
            const pkgPath = tryResolve(`textlint-formatter-${formatterName}`) || tryResolve(formatterName);
            if (pkgPath) {
                formatterPath = pkgPath;
            }
        }
    }
    try {
        formatter = module_interop_1.moduleInterop(require(formatterPath));
    }
    catch (ex) {
        throw new Error(`Could not find formatter ${formatterName}
${ex}`);
    }
    return function (results) {
        return formatter(results, formatterConfig);
    };
}
exports.createFormatter = createFormatter;
function getFormatterList() {
    return fs
        .readdirSync(path.join(__dirname, "formatters"))
        .filter((file) => {
        return path.extname(file) === ".js";
    })
        .map((file) => {
        return { name: path.basename(file, ".js") };
    });
}
exports.getFormatterList = getFormatterList;
//# sourceMappingURL=index.js.map